aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core
diff options
context:
space:
mode:
authorGravatar tomhudson@google.com <tomhudson@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-12-28 17:58:07 +0000
committerGravatar tomhudson@google.com <tomhudson@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-12-28 17:58:07 +0000
commit4714359ec091b34a4f88eb9708868a58a22177d3 (patch)
tree540246da2514658a244eed3bf6c7d53fd2a628b5 /include/core
parent6fc7cc23a9c33960b879f69d92d6fb0e1373e556 (diff)
Bugfixes to antialiased blitting.
More details of blitter contracts in function headers. New precautionary assert in one high-level default blitter. git-svn-id: http://skia.googlecode.com/svn/trunk@2928 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/core')
-rw-r--r--include/core/SkBlitter.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/core/SkBlitter.h b/include/core/SkBlitter.h
index beaebfeccd..e784ef5e23 100644
--- a/include/core/SkBlitter.h
+++ b/include/core/SkBlitter.h
@@ -24,7 +24,7 @@ class SkBlitter {
public:
virtual ~SkBlitter();
/// Blit a horizontal run of pixels.
virtual void blitH(int x, int y, int width);
/// Blit a horizontal run of antialiased pixels; runs[] is a *sparse*
/// zero-terminated run-length encoding of spans of constant alpha values.
@@ -32,11 +32,12 @@ public:
const int16_t runs[]);
/// Blit a vertical run of pixels with a constant alpha value.
virtual void blitV(int x, int y, int height, SkAlpha alpha);
- /// Blit a solid rectangle.
+ /// Blit a solid rectangle zero or more pixels wide.
virtual void blitRect(int x, int y, int width, int height);
/** Blit a rectangle with one alpha-blended column on the left,
- width opaque pixels, and one alpha-blended column on the right.
- Note that the result will always be at least two pixels wide.
+ width (zero or more) opaque pixels, and one alpha-blended column
+ on the right.
+ The result will always be at least two pixels wide.
*/
virtual void blitAntiRect(int x, int y, int width, int height,
SkAlpha leftAlpha, SkAlpha rightAlpha);
@@ -24,7 +24,7 @@ class SkBlitter {
public:
virtual ~SkBlitter();
- /// Blit a horizontal run of pixels.
+ /// Blit a horizontal run of zero or more pixels.
virtual void blitH(int x, int y, int width);
/// Blit a horizontal run of antialiased pixels; runs[] is a *sparse*